from .task import TaskBase
from .funcaptcha import FuncaptchaTask
from .hcaptcha import HCaptchaTask, HCaptchaEnterpriseTask
from .recaptcha import ReCaptchaV3Task